@@ -202,5 +202,18 @@ describe 'keystone::federation::openidc' do
         expect(content).to match('OIDCPassClaimsAs "both"')
       end
     end
+
+    context 'with openidc_response_mode attribute' do
+      before do
+        params.merge!({
+          :openidc_response_mode => 'form_post',
+        })
+      end
+
+      it 'should contain OIDC response mode' do
+        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        expect(content).to match('OIDCResponseMode "form_post"')
+      end
+    end
   end
 end
