@@ -10,8 +10,9 @@ describe 'keystone' do
       it { is_expected.to contain_class('keystone::policy') }
 
       it { is_expected.to contain_package('keystone').with(
-        'ensure' => 'present',
-        'tag'    => ['openstack', 'keystone-package'],
+        :ensure => 'present',
+        :name   => platform_params[:package_name],
+        :tag    => ['openstack', 'keystone-package'],
       ) }
 
       it { is_expected.to contain_class('keystone::client').with(
@@ -38,12 +39,12 @@ describe 'keystone' do
         is_expected.to contain_keystone_config('identity/password_hash_rounds').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('revoke/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('policy/driver').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('ssl/enable').with_value(false)
-        is_expected.to contain_keystone_config('ssl/certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('ssl/keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('ssl/ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('ssl/ca_key').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('ssl/cert_subject').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/enable').with_ensure('absent')
+        is_expected.to contain_keystone_config('ssl/certfile').with_ensure('absent')
+        is_expected.to contain_keystone_config('ssl/keyfile').with_ensure('absent')
+        is_expected.to contain_keystone_config('ssl/ca_certs').with_ensure('absent')
+        is_expected.to contain_keystone_config('ssl/ca_key').with_ensure('absent')
+        is_expected.to contain_keystone_config('ssl/cert_subject').with_ensure('absent')
         is_expected.to contain_keystone_config('token/revoke_by_id').with_value(true)
 
         is_expected.to contain_oslo__middleware('keystone_config').with(
@@ -56,6 +57,7 @@ describe 'keystone' do
         is_expected.to contain_keystone_config('token/provider').with_value('fernet')
         is_expected.to contain_keystone_config('DEFAULT/max_token_size').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('DEFAULT/notification_format').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('DEFAULT/notification_opt_out').with_value('<SERVICE DEFAULT>')
 
         is_expected.to contain_oslo__messaging__default('keystone_config').with(
           :transport_url        => '<SERVICE DEFAULT>',
@@ -134,6 +136,11 @@ describe 'keystone' do
           :token_provider               => 'uuid',
           :max_token_size               => 255,
           :notification_format          => 'basic',
+          :notification_opt_out         => [
+            'identity.authenticate.success',
+            'identity.authenticate.pending',
+            'identity.authenticate.failed'
+            ],
         }
       end
 
@@ -145,12 +152,6 @@ describe 'keystone' do
         is_expected.to contain_keystone_config('identity/password_hash_rounds').with_value(12)
         is_expected.to contain_keystone_config('revoke/driver').with_value('sql')
         is_expected.to contain_keystone_config('policy/driver').with_value('sql')
-        is_expected.to contain_keystone_config('ssl/enable').with_value(false)
-        is_expected.to contain_keystone_config('ssl/certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('ssl/keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('ssl/ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('ssl/ca_key').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_keystone_config('ssl/cert_subject').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('token/revoke_by_id').with_value(true)
 
         is_expected.to contain_oslo__middleware('keystone_config').with(
@@ -163,6 +164,11 @@ describe 'keystone' do
         is_expected.to contain_keystone_config('token/provider').with_value('uuid')
         is_expected.to contain_keystone_config('DEFAULT/max_token_size').with_value(255)
         is_expected.to contain_keystone_config('DEFAULT/notification_format').with_value('basic')
+        is_expected.to contain_keystone_config('DEFAULT/notification_opt_out').with_value([
+          'identity.authenticate.success',
+          'identity.authenticate.pending',
+          'identity.authenticate.failed'
+        ])
       end
     end
 
@@ -177,9 +183,16 @@ describe 'keystone' do
       end
 
       it do
-        expect {
-          is_expected.to contain_service(platform_params[:service_name]).with('ensure' => 'running')
-        }.to raise_error(RSpec::Expectations::ExpectationNotMetError, /expected that the catalogue would contain Service\[#{platform_params[:service_name]}\]/)
+        if facts[:operatingsystem] == 'Debian'
+          is_expected.to contain_service('keystone').with(
+            :ensure => 'stopped',
+            :name   => platform_params[:service_name],
+            :enable => false,
+            :tag    => 'keystone-service',
+          )
+        else
+          is_expected.to_not contain_service('keystone')
+        end
       end
 
       it { is_expected.to contain_exec('restart_keystone').with(
@@ -221,20 +234,6 @@ describe 'keystone' do
       it { is_expected.not_to contain_exec('keystone-manage db_sync') }
     end
 
-    context 'when enabling SSL' do
-      let :params do
-        {
-          'enable_ssl'  => true,
-        }
-      end
-      it {is_expected.to contain_keystone_config('ssl/enable').with_value(true)}
-      it {is_expected.to contain_keystone_config('ssl/certfile').with_value('/etc/keystone/ssl/certs/keystone.pem')}
-      it {is_expected.to contain_keystone_config('ssl/keyfile').with_value('/etc/keystone/ssl/private/keystonekey.pem')}
-      it {is_expected.to contain_keystone_config('ssl/ca_certs').with_value('/etc/keystone/ssl/certs/ca.pem')}
-      it {is_expected.to contain_keystone_config('ssl/ca_key').with_value('/etc/keystone/ssl/private/cakey.pem')}
-      it {is_expected.to contain_keystone_config('ssl/cert_subject').with_value('/C=US/ST=Unset/L=Unset/O=Unset/CN=localhost')}
-    end
-
     context 'with RabbitMQ communication SSLed' do
       let :params do
         {
@@ -379,11 +378,13 @@ describe 'keystone' do
       it { is_expected.to contain_file('/etc/keystone/credential-keys/0').with(
         'content'   => 't-WdduhORSqoyAykuqWAQSYjg2rSRuJYySgI2xh48CI=',
         'owner'     => 'keystone',
+        :show_diff  => false,
         'subscribe' => 'Anchor[keystone::install::end]',
       )}
       it { is_expected.to contain_file('/etc/keystone/credential-keys/1').with(
         'content'   => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
         'owner'     => 'keystone',
+        :show_diff  => false,
         'subscribe' => 'Anchor[keystone::install::end]',
       )}
     end
@@ -638,7 +639,7 @@ describe 'keystone' do
             :service_name       => 'keystone',
             :httpd_service_name => 'apache2' }
         when 'RedHat'
-          { :package_name       => 'opnestack-keystone',
+          { :package_name       => 'openstack-keystone',
             :service_name       => 'openstack-keystone',
             :httpd_service_name => 'httpd' }
         end
