@@ -5,7 +5,6 @@ describe 'keystone::wsgi::apache' do
   let :pre_condition do
     "class { 'keystone':
        service_name => 'httpd',
-       enable_ssl   => true,
      }"
   end
 
@@ -24,8 +23,8 @@ describe 'keystone::wsgi::apache' do
         :workers                     => facts[:os_workers_keystone],
         :threads                     => 1,
         :user                        => 'keystone',
-        :priority                    => '10',
-        :ssl                         => true,
+        :priority                    => 10,
+        :ssl                         => false,
         :wsgi_daemon_process         => 'keystone',
         :wsgi_process_display_name   => 'keystone',
         :wsgi_process_group          => 'keystone',
@@ -35,11 +34,12 @@ describe 'keystone::wsgi::apache' do
         :wsgi_script_source          => '/usr/bin/keystone-wsgi-public',
         :wsgi_pass_authorization     => 'On',
         :headers                     => nil,
+        :request_headers             => nil,
         :custom_wsgi_process_options => {},
-        :access_log_file             => false,
-        :access_log_pipe             => false,
-        :access_log_syslog           => false,
-        :access_log_format           => false,
+        :access_log_file             => nil,
+        :access_log_pipe             => nil,
+        :access_log_syslog           => nil,
+        :access_log_format           => nil,
         :error_log_file              => nil,
         :error_log_pipe              => nil,
         :error_log_syslog            => nil,
@@ -51,24 +51,25 @@ describe 'keystone::wsgi::apache' do
         {
           :servername                  => 'dummy.host',
           :bind_host                   => '127.0.0.1',
-          :api_port                    => 1234,
+          :port                        => 1234,
           :path                        => '/keystone',
-          :ssl                         => false,
+          :ssl                         => true,
           :workers                     => 10,
-          :ssl_cert                    => 'ssl cert',
-          :ssl_key                     => 'ssl key',
-          :ssl_chain                   => 'ssl chain',
-          :ssl_ca                      => 'ssl ca',
-          :ssl_crl_path                => '/etc/ssl',
-          :ssl_crl                     => 'crl',
+          :ssl_cert                    => '/etc/ssl/certs/keystone.crt',
+          :ssl_key                     => '/etc/ssl/private/keystone.key',
+          :ssl_chain                   => '/etc/ssl/certs/chain.pem',
+          :ssl_ca                      => '/etc/ssl/certs/ca.pem',
+          :ssl_crl_path                => '/etc/ssl/crl',
+          :ssl_crl                     => '/etc/ssl/certs/crl.crt',
           :ssl_certs_dir               => '/etc/ssl/certs',
           :threads                     => 10,
-          :priority                    => '20',
+          :priority                    => 20,
           :wsgi_application_group      => 'group',
           :wsgi_pass_authorization     => 'Off',
           :wsgi_chunked_request        => 'On',
           :wsgi_script_source          => '/path/to/my/script.py',
-          :headers                     => 'set X-Frame-Options "DENY"',
+          :headers                     => ['set X-XSS-Protection "1; mode=block"'],
+          :request_headers             => ['set Content-Type "application/json"'],
           :vhost_custom_fragment       => 'custom',
           :custom_wsgi_process_options => { 'python-path' => '/my/python/virtualenv' },
         }
@@ -77,7 +78,7 @@ describe 'keystone::wsgi::apache' do
       it { should contain_openstacklib__wsgi__apache('keystone_wsgi').with(
         :servername                  => params[:servername],
         :bind_host                   => params[:bind_host],
-        :bind_port                   => params[:api_port],
+        :bind_port                   => params[:port],
         :path                        => params[:path],
         :workers                     => params[:workers],
         :threads                     => params[:threads],
@@ -95,6 +96,7 @@ describe 'keystone::wsgi::apache' do
         :wsgi_chunked_request        => params[:wsgi_chunked_request],
         :wsgi_script_source          => params[:wsgi_script_source],
         :headers                     => params[:headers],
+        :request_headers             => params[:request_headers],
         :vhost_custom_fragment       => params[:vhost_custom_fragment],
         :custom_wsgi_process_options => params[:custom_wsgi_process_options],
       )}
@@ -103,7 +105,7 @@ describe 'keystone::wsgi::apache' do
     context 'with backward compatible ports' do
       let :params do
         {
-          :api_port => [35357, 5000],
+          :port => [35357, 5000],
         }
       end
 
@@ -202,15 +204,11 @@ describe 'keystone::wsgi::apache' do
         case facts[:osfamily]
         when 'Debian'
           {
-            :httpd_service_name => 'apache2',
-            :httpd_ports_file   => '/etc/apache2/ports.conf',
-            :wsgi_script_path   => '/usr/lib/cgi-bin/keystone',
+            :wsgi_script_path => '/usr/lib/cgi-bin/keystone',
           }
         when 'RedHat'
           {
-            :httpd_service_name => 'httpd',
-            :httpd_ports_file   => '/etc/httpd/conf/ports.conf',
-            :wsgi_script_path   => '/var/www/cgi-bin/keystone',
+            :wsgi_script_path => '/var/www/cgi-bin/keystone',
           }
         end
       end
