@@ -45,6 +45,8 @@ describe 'keystone::resource::service_identity' do
         :roles  => ['admin'],
       )}
 
+      it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
+
       it { is_expected.to contain_keystone_service("#{title}::network").with(
         :ensure      => 'present',
         :description => 'neutron service',
@@ -75,6 +77,8 @@ describe 'keystone::resource::service_identity' do
         :roles  => ['admin'],
       )}
 
+      it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
+
       it { is_expected.to contain_keystone_service("#{title}::network").with(
         :ensure      => 'absent',
         :description => 'neutron service',
@@ -168,6 +172,8 @@ describe 'keystone::resource::service_identity' do
         :ensure => 'present',
         :roles  => ['admin'],
       )}
+
+      it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
     end
 
     context 'with user and project domain' do
@@ -193,6 +199,8 @@ describe 'keystone::resource::service_identity' do
         :ensure => 'present',
         :roles  => ['admin'],
       )}
+
+      it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
     end
 
     context 'with default domain only' do
@@ -217,6 +225,27 @@ describe 'keystone::resource::service_identity' do
         :ensure => 'present',
         :roles  => ['admin'],
       )}
+
+      it { is_expected.to_not contain_keystone_user_role("#{title}@::::all") }
+    end
+
+    context 'with customized roles' do
+      let :params do
+        required_params.merge({
+          :roles        => ['admin', 'service'],
+          :system_roles => ['member', 'reader']
+        })
+      end
+
+      it { is_expected.to contain_keystone_user_role("#{title}@services").with(
+        :ensure => 'present',
+        :roles  => ['admin', 'service'],
+      )}
+
+      it { is_expected.to contain_keystone_user_role("#{title}@::::all").with(
+        :ensure => 'present',
+        :roles  => ['member', 'reader'],
+      )}
     end
   end
 
